from scrapemove.models.combined_details import CombinedDetails
from scrapemove.models.property_details_screen import (
    PropertyDetails,
    PropertyDetailsScreenData,
    Station,
)
from scrapemove.models.results_screen import (
    ListingUpdate,
    Location,
    Pagination,
    PaginationOption,
    Price,
    Property,
    ResultsScreenData,
)
